#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hasql-dynamic-statements
version:              0.3.1.2
visibility:           public
id:                   hasql-dynamic-statements-0.3.1.2-JTROPCOLgNPJ2Zebw7kIPH
key:                  hasql-dynamic-statements-0.3.1.2-JTROPCOLgNPJ2Zebw7kIPH
license:              MIT
copyright:            (c) 2019, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/hasql-dynamic-statements
synopsis:             Toolkit for constructing Hasql statements dynamically
description:
    This library introduces into the Hasql ecosystem a new abstraction named Snippet,
    which makes it trivial to construct SQL, while injecting values.
    It is intended to be used when the SQL of your statement depends on the parameters,
    that you want to pass in.

abi:                  75add5d493712cb07160e917332a152f
exposed:              True
exposed-modules:
    Hasql.DynamicStatements.Session Hasql.DynamicStatements.Snippet
    Hasql.DynamicStatements.Statement

hidden-modules:
    Hasql.DynamicStatements.Prelude
    Hasql.DynamicStatements.Snippet.Defs

import-dirs:
    /usr/lib/ghc-9.6.6/site-local/hasql-dynamic-statements-0.3.1.2

library-dirs:
    /usr/lib/ghc-9.6.6/site-local/hasql-dynamic-statements-0.3.1.2

library-dirs-static:
    /usr/lib/ghc-9.6.6/site-local/hasql-dynamic-statements-0.3.1.2

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hasql-dynamic-statements
hs-libraries:         HShasql-dynamic-statements-0.3.1.2-JTROPCOLgNPJ2Zebw7kIPH
depends:
    base-4.18.2.1 bytestring-0.11.5.3 containers-0.6.7
    hasql-1.6.1.1-8ijriLMpmIy3XMWtxmnUHr
    hasql-implicits-0.1.1.2-2A4r3XjV5dzFklLPrExjrT
    ptr-0.16.8.7-4fiEgvFqDjyKq4iik9qC8t

haddock-interfaces:
    /usr/share/doc/haskell-hasql-dynamic-statements/html/hasql-dynamic-statements.haddock

haddock-html:         /usr/share/doc/haskell-hasql-dynamic-statements/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

